==> home-library-jcr-1.0.1-20140205.164525-68-sources.jar: org/gcube/common/homelibrary/jcr/workspace/folder/items/JCRExternalUrl.java <==
package org.gcube.common.homelibrary.jcr.workspace.folder.items;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import org.apache.commons.lang.Validate;
import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.common.homelibrary.home.workspace.folder.items.ExternalUrl;
import org.gcube.common.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.common.homelibrary.util.Util;
import org.gcube.contentmanagement.blobstorage.transport.backend.RemoteBackendException;

public class JCRExternalUrl extends JCRWorkspaceFolderItem implements
		ExternalUrl {
	

	
	protected final JCRFile content;
	
	public JCRExternalUrl(JCRWorkspace workspace, Node node) throws RepositoryException, InternalErrorException {
		super(workspace,node);
		this.content = new JCRFile(node.getNode(CONTENT));
	}

	public JCRExternalUrl(JCRWorkspace workspace, Node node, String name, String description,
			String url) throws RepositoryException, RemoteBackendException  {
		super(workspace, node, name, description);
		
		Validate.notNull(url, "url must be not null");

		this.content = new JCRFile(node.addNode(CONTENT,ContentType.GENERAL.toString()),
				new ByteArrayInputStream(url.getBytes()));
		node.setProperty(FOLDER_ITEM_TYPE, FolderItemType.EXTERNAL_URL.toString());	
	}

	@Override
	public long getLength() throws InternalErrorException {
		
		return content.getLength();
		
	}

	@Override
	public String getUrl() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData()));
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_URL;
	}

	@Override
	public void saveContent(Node node) throws RepositoryException {
		content.save(node);
	}

	
	@Override
	public String getMimeType() throws InternalErrorException {
		return null;
	}

}

==> home-library-jcr-1.7.1-3.7.0-sources.jar: org/gcube/common/homelibrary/jcr/workspace/folder/items/JCRExternalUrl.java <==
package org.gcube.common.homelibrary.jcr.workspace.folder.items;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import org.apache.commons.lang.Validate;
import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.common.homelibrary.home.workspace.folder.items.ExternalUrl;
import org.gcube.common.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.common.homelibrary.util.Util;
import org.gcube.contentmanagement.blobstorage.transport.backend.RemoteBackendException;

public class JCRExternalUrl extends JCRWorkspaceFolderItem implements
		ExternalUrl {
	

	
	protected final JCRFile content;
	
	public JCRExternalUrl(JCRWorkspace workspace, Node node) throws RepositoryException, InternalErrorException {
		super(workspace,node);
		this.content = new JCRFile(workspace, node.getNode(CONTENT));
	}

	public JCRExternalUrl(JCRWorkspace workspace, Node node, String name, String description,
			String url) throws RepositoryException, RemoteBackendException{
		super(workspace, node, name, description);
		
		Validate.notNull(url, "url must be not null");

		this.content = new JCRFile(workspace, node.addNode(CONTENT,ContentType.GENERAL.toString()),
				new ByteArrayInputStream(url.getBytes()));
		
		node.setProperty(FOLDER_ITEM_TYPE, FolderItemType.EXTERNAL_URL.toString());	
	}

	@Override
	public long getLength() throws InternalErrorException {
		
		return content.getLength();
		
	}

	@Override
	public String getUrl() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData()));
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_URL;
	}

	@Override
	public void saveContent(Node node) throws RepositoryException {
		content.save(node);
	}

	
	@Override
	public String getMimeType() throws InternalErrorException {
		return null;
	}

}
